.. include:: ../../README.rst

Thamos Python client
====================

* :ref:`openapi`

Crossroad
=========

* `Documentation for thoth-adviser <../adviser>`_
* `Documentation for thoth-analyzer <../analyzer>`_
* `Documentation for thoth-common <../common>`_
* `Documentation for thoth-lab <../lab>`_
* `Documentation for thoth-package-analyzer <../package-analyzer>`_
* `Documentation for thoth-package-extract <../package-extract>`_
* `Documentation for thoth-python <../python>`_
* `Documentation for thoth-storages <../storages>`_
* `Documentation for thoth-solver <../solver>`_
* `Documentation for kebechet <../kebechet>`_
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. toctree::
   :maxdepth: 3

   thamos

This documentation corresponds to implementation in version |version|,
documentation was generated on |today|.
